{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![Callysto.ca Banner](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-top.jpg?raw=true)\n",
    "\n",
    "<a href=\"https://hub.callysto.ca/jupyter/hub/user-redirect/git-pull?repo=https%3A%2F%2Fgithub.com%2Fcallysto%2Fcurriculum-notebooks&branch=master&subPath=Science/ElectricityConsumptionMonitoring/electricity-consumption-monitoring.ipynb&depth=1\" target=\"_parent\"><img src=\"https://raw.githubusercontent.com/callysto/curriculum-notebooks/master/open-in-callysto-button.svg?sanitize=true\" width=\"123\" height=\"24\" alt=\"Open in Callysto\"/></a>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Electricity Consumption Monitoring "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Instructions before you start:\n",
    "Once the notebook has loaded, click the fast forward button \">>\" in the menu bar above. Click \"Yes\" to restart and run."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "%%html\n",
    "<button onclick=\"run_all()\">Run All Cells</button> \n",
    "<script>\n",
    "function run_all(){\n",
    "    Jupyter.actions.call('jupyter-notebook:run-all-cells-below');\n",
    "    Jupyter.actions.call('jupyter-notebook:save-notebook');\n",
    "}\n",
    "</script>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "%%html\n",
    "\n",
    "<script>\n",
    "function code_toggle() {\n",
    "    if (code_shown){\n",
    "      $('div.input').hide('500');\n",
    "      $('#toggleButton').val('Show Code')\n",
    "    } else {\n",
    "      $('div.input').show('500');\n",
    "      $('#toggleButton').val('Hide Code')\n",
    "    }\n",
    "    code_shown = !code_shown\n",
    "}\n",
    "    \n",
    "$( document ).ready(function(){ code_shown=false; $('div.input').hide() });\n",
    "</script>\n",
    "\n",
    "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "\n",
    "\n",
    "## Introduction\n",
    "\n",
    "In this notebook we will be discussing what electricity is, how it is used and how it is monitored. We will also be discussing what circuit diagrams are and how they relate to electricity in your homes."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### What is Electricity?\n",
    "\n",
    "In simplest terms electricity is the presence or flow of electrons. If you don't remember what electrons are from your other science courses they are found in atoms. Atoms are the basic building blocks of matter. \n",
    "\n",
    "<img src=\"images/atom.png\" alt=\"\" width=500 align=middle>\n",
    "\n",
    "You can find electrons, protons and neutrons in an atom. Negatively charged electrons orbit around the nucleus of the atom which is made up of positively charged protons and neutrons with no charge. Electrons are attracted to the protons in the nucleus. Electrons are much lighter than the nucleus and can be transferred from one atom to another.\n",
    "\n",
    "\n",
    "### Static and Current Electricity\n",
    "\n",
    "Two types of electricity will be discussed, static and current electricity. **Static Electricity** is the build up of electrons on an object. A static charge can be formed when the electrons on one object move to another. An example of this would be sliding down a slide and your hair standing on end. \n",
    "\n",
    "<img src=\"images/staticCharge.jpg\" alt=\"\" width=500 align=middle>\n",
    "\n",
    "This results from electrons being transferred from you to the slide leaving you with a net positive charge. You are left with positive charge at the ends of your hair causing them to be repelled from each other and making them stand up.\n",
    "\n",
    "The other type of electricity is current electricity. **Current Electricity** is the flow of electrons or electrical energy from one atom to another and in general terms from one place to another. \n",
    "\n",
    "<img src=\"images/electricCurrentAnimation.gif\" alt=\"\" width=500 align=middle>\n",
    "\n",
    "Current electricity is normally called **Electric Current**. An example of an electric current would be charging your cell phone. \n",
    "\n",
    "<img src=\"images/electricCurrent.jpg\" alt=\"\" width=500 align=middle>\n",
    "\n",
    "Electrons flow from your cell phone charger through the charging cord and into your cell phone creating an electric current. In this notebook we will be focusing on current electricity or electric current and how it is monitored and used throughout our homes. In the rest of the notebook electrical current will generally be referred to as just electricity.\n",
    "\n",
    "### Electricity Units\n",
    "Before we move on to the rest of the notebook we need to cover the units that are used when measuring the amount of electricity being used. As electrical current travels through a device the electrons lose energy which can be used to do useful things like produce heat or do work like turning motors. We are often interested how fast this energy is being used, that is **Power**. The unit used to measure the power or the rate of electricity being used is **Watts (W)**. A Watt is one Joule of energy transferred per second.  The power used by a device when it is on is given in Watts.\n",
    "\n",
    "Another unit of energy that is used is the **Watt-hour**. A **Watt-hour (Wh)** describes the total amount of electricity (energy) used over the course of an hour. It is a combination of how fast electrical power is being used. To get a better understanding of a Watt-hour let's convert it to Joules of energy.\n",
    "\n",
    "> A Watt measures the amount of Joules per second and can be written as:\n",
    ">\n",
    "> $\\large 1 \\hspace{1mm} \\text{Watt} = 1 \\hspace{1mm} \\text{W} = 1\\hspace{1mm}\\frac{\\text{Joule}}{\\text{second}} = 1\\hspace{1mm}\\frac{\\text{J}}{\\text{s}}$ \n",
    ">\n",
    "> In an hour there are 60 minutes and 60 seconds in each minute. The total number of seconds in an hour would be 60x60 = 3600 seconds\n",
    ">\n",
    "> $\\large 1 \\hspace{1mm} \\text{hour} = 3600 \\hspace{1mm} \\text{seconds} = 3600 \\hspace{1mm}\\text{s}$\n",
    "> \n",
    "> Thus in 1 Watt-hour we have 1 J being used every second over the course of an hour. If a Joule is used every second of the hour and there are 3600 seconds in the hour then 1 Watt-hour is equivalent to 3600 Joules.\n",
    ">\n",
    "> $\\large 1 \\hspace{1mm} \\text{Wh} = 1\\hspace{1mm}\\frac{\\text{J}}{\\text{s}} \\times 3600 \\hspace{1mm}\\text{s} = 3600 \\hspace{1mm}\\text{J}$ \n",
    ">\n",
    "> Compared to the Joule, a Watt-hour is a more convenient unit to measure the amount of energy consumed by an item over the course of some time.\n",
    "\n",
    "### Kilo, Mega and Giga \n",
    "\n",
    "Some other terms you may see in this notebook are **kilowatts (kW)**, **megawatts (MW)** and **gigawatts (GW)**. A kilowatt is 1000 watts, a megawatt is 1 million watts and a gigawatt is 1 billion watts. You will also see the term **kilowatt-hours (kWh)** which is 1000 Watt-hours. It can also be thought of as using electricity for 1 hour at a rate of 1000 watts. \n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Electricity Use\n",
    "\n",
    "It is common knowledge that electricity is used to power our homes, vehicles and the various electronic devices we use on a daily basis. So how much electrical power does it actually take to charge your smart phone, use your oven or run a refrigerator? In this section we will answer those questions and take a look at the electricity use of various electronic devices.\n",
    "\n",
    "### Efficiency Labels\n",
    "\n",
    "If you have ever looked at the back of a washing machine, dryer or other electrical appliances you may have noticed a label giving a number of kilowatt-hours (kWh) per year. This label is known as an efficiency label giving energy-related information about the product. In Canada this label is known as the EnerGuide label. Examples of this label are below.\n",
    "\n",
    "<table>\n",
    "<tr>\n",
    "    <td><img src=\"images/label1.jpg\" alt=\"EnerGuide\" width=\"450\"/></td>\n",
    "    <td><img src=\"images/label2.jpg\" alt=\"EnerGuide&EnergyStar\" width=\"450\"/></td>\n",
    "</tr>\n",
    "</table>\n",
    "\n",
    "There are four key pieces of information that the EnerGuide label tells us:\n",
    "\n",
    "1. It tells us the annual energy consumption of the appliance in kilowatt-hours. \n",
    "2. On the label it has the annual energy consumption for the most efficienct and least efficient models and were the appliance falls in between them. \n",
    "3. The energy consumption indicator positions the appliance model based on a comparison of other models in the same class. \n",
    "4. The label also has the type and capacity of models that make up the appliance class as well as the model number. \n",
    "\n",
    "We are most interested in the annual energy consumption since it tells us the average amount of electricity the appliance uses over the course of a year. It should be noted that not all electrical appliances  have an EnerGuide label as it is not manadatory for all electrical appliances."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Device Electrical Power Use\n",
    "\n",
    "Now that we have gotten the terminology and brief introduction about electricity over we can look at how much electricity everyday devices actually use. Below is table of various devices and their average kWh usage.\n",
    "\n",
    "<table> \n",
    "    <tr>\n",
    "        <th>Electrical Devices/Appliances</th> \n",
    "        <th>Device Power Usage</th> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Portable Heater (1500 W)</td> \n",
    "        <td>1.5 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Electric Furnace (with fan)</td> \n",
    "        <td>10.0 kWh per hour</td> \n",
    "    </tr>\n",
    "    <tr> \n",
    "        <td>Central Air Conditioner (3 ton)</td> \n",
    "        <td>3.0 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Ceiling Fan</td> \n",
    "        <td>0.075 kWh per hour</td> \n",
    "    </tr>\n",
    "    <tr> \n",
    "        <td>Oven</td> \n",
    "        <td>2.3 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Microwave Oven</td> \n",
    "        <td>1.0 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Coffee Maker</td> \n",
    "        <td>0.12 kWh per brew</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Dishwasher</td> \n",
    "        <td>0.6 kWh per load</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Toaster</td> \n",
    "        <td>0.04 kWh per use</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Refrigerator</td> \n",
    "        <td>0.05 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Plasma TV (40-49 inches)</td> \n",
    "        <td>0.4 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>LCD TV (40-49 inches)</td> \n",
    "        <td>0.012 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Desktop Computer</td> \n",
    "        <td>0.15 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Laptop</td> \n",
    "        <td>0.03 kWh per hour</td> \n",
    "    </tr>     \n",
    "    <tr> \n",
    "        <td>Radio</td> \n",
    "        <td>0.02 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Clothes Washer (500 W)</td> \n",
    "        <td>0.5 kWh per load</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Clothes Dryer (5000 W)</td> \n",
    "        <td>5.0 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Vacuum Cleaner</td> \n",
    "        <td>0.75 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Iron</td> \n",
    "        <td>1.08 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Hair Dryer</td> \n",
    "        <td>1.5 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Curling Iron</td> \n",
    "        <td>0.05 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Incandescent Light Bulb (60 W)</td> \n",
    "        <td>0.06 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Compact Flourescent (15 W)</td> \n",
    "        <td>0.015 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Halogen Light Bulb (300 W)</td> \n",
    "        <td>0.3 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Xbox One (Playing a Game)</td> \n",
    "        <td>0.112 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Playstation 4 (Playing a Game)</td> \n",
    "        <td>0.137 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Wii U (Playing a Game)</td> \n",
    "        <td>0.034 kWh per hour</td> \n",
    "    </tr> \n",
    "    <tr> \n",
    "        <td>Cellphone</td> \n",
    "        <td>0.01 kWh per hour</td> \n",
    "    </tr> \n",
    "</table>\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "If you want to determine how much electricity you have used for a device on the table above you can use the calculator below.  The energy used is just the power times the amount of time or number of usages. All you have to do is select the device and then enter the amount of hours the device was used for. Depending on the device selected you may enter the number of loads done or times it was used instead of the hours."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "045f15b5e5d54e209dc163098030f052",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "VBox(children=(HBox(children=(HTML(value='<font size=\"4\"> Device: </font>'), Dropdown(layout=Layout(width='150…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import ipywidgets as widgets\n",
    "from IPython.display import display, Math, Latex\n",
    "import traitlets\n",
    "from IPython.display import Markdown as md\n",
    "import random\n",
    "\n",
    "error = False\n",
    "\n",
    "usage_list = [0.0, 1.5, 10.0, 3.0, 0.075, 2.3, 1.0, 0.12, 0.6, 0.04, 0.05, 0.4, 0.012, 0.15, 0.03, 0.02, 0.5, 5.0, 0.75, 1.08, 1.5, 0.05, 0.06, 0.015, 0.3, 0.112, 0.137, 0.034, 0.01]\n",
    "\n",
    "output1 = widgets.HTML(\n",
    "    value='<font size=\"4\"> Device: </font>',\n",
    ")\n",
    "output2 = widgets.HTML(\n",
    "    value='<font size=\"4\"> Number of Hours: </font>',\n",
    ")\n",
    "\n",
    "calculation_output = widgets.HTML('')\n",
    "error_output = widgets.HTML('')\n",
    "\n",
    "device_choice = widgets.Dropdown(\n",
    "    options={' ':0,'Portable Heater': 1, 'Electric Furnace': 2, 'Air Conditioner': 3, 'Ceiling Fan': 4, 'Oven': 5, 'Microwave Oven': 6, 'Coffee Maker': 7, 'Dishwasher': 8, 'Toaster': 9, 'Refrigerator': 10, 'Plasma TV': 11, 'LCD TV': 12, 'Desktop Computer': 13, 'Laptop': 14, 'Radio': 15, 'Clothes Washer':16, 'Clothes Dryer': 17, 'Vacuum Cleaner': 18, 'Iron': 19, 'Hair Dryer': 20, 'Curling Iron': 21, 'Incandescent Bulb': 22, 'Compact Flourescent': 23, 'Halogen Bulb': 24, 'Xbox One': 25, 'Playstation 4': 26, 'Wii U': 27, 'Cellphone Charge': 28},\n",
    "    value=0,\n",
    "    description='',\n",
    ")\n",
    "\n",
    "hours_input = widgets.Text(\n",
    "    value='0',\n",
    "    placeholder='',\n",
    "    description='',\n",
    "    disabled=False   \n",
    ")\n",
    "\n",
    "calculate_button = widgets.Button(\n",
    "    value=False,\n",
    "    description='Calculate',\n",
    "    disabled=False,\n",
    "    button_style='', # 'success', 'info', 'warning', 'danger' or ''\n",
    "    tooltip='Calculate the number of kWh',\n",
    "    continuous_update=True\n",
    ")\n",
    "\n",
    "device_choice.layout.width = '150px'\n",
    "hours_input.layout.width = '100px'\n",
    "\n",
    "device_widget = widgets.HBox(children=[output1, device_choice])\n",
    "hours_widget = widgets.HBox(children=[output2, hours_input])\n",
    "\n",
    "display_widget = widgets.VBox(children=[device_widget, hours_widget, calculate_button, calculation_output, error_output])\n",
    "\n",
    "\n",
    "def calculate_output(change):\n",
    "    global error\n",
    "    global usage_list\n",
    "    \n",
    "    calculation_output.value = ''\n",
    "    error_output.value = ''\n",
    "    error = False\n",
    "    \n",
    "    check_error()\n",
    "    \n",
    "    if(not(error)):\n",
    "        input_hours = float(hours_input.value)\n",
    "        kwh = usage_list[device_choice.value]*input_hours\n",
    "        kwh = round(kwh, 3)\n",
    "        \n",
    "        calculation_output.value = '<font size=\"4\"> ' + str(kwh) + ' kWh used.</font>'\n",
    "        \n",
    "        \n",
    "def check_error():\n",
    "    global error\n",
    "    \n",
    "    if(device_choice.value == 0):\n",
    "        error_output.value = '<font size=\"4\"> ERROR: You have not selected a device.</font>'\n",
    "        error = True\n",
    "    else:\n",
    "        try:\n",
    "            input_hours = float(hours_input.value)\n",
    "        except ValueError:\n",
    "            error_output.value = '<font size=\"4\"> ERROR: That is not a valid number.  Please enter a valid number.</font>'\n",
    "            error = True\n",
    "\n",
    "            \n",
    "def check_value(change):\n",
    "    if(device_choice.value == 7):\n",
    "        output2.value='<font size=\"4\"> Number of Brews: </font>'\n",
    "    elif(device_choice.value == 8):\n",
    "        output2.value='<font size=\"4\"> Number of Loads: </font>'\n",
    "    elif(device_choice.value == 9):\n",
    "        output2.value='<font size=\"4\"> Number of Uses: </font>'\n",
    "    elif(device_choice.value == 16):\n",
    "        output2.value='<font size=\"4\"> Number of Loads: </font>'\n",
    "    else:\n",
    "        output2.value='<font size=\"4\"> Number of Hours: </font>'\n",
    "            \n",
    "\n",
    "calculate_button.on_click(calculate_output)\n",
    "device_choice.observe(check_value, names='value')\n",
    "\n",
    "display_widget"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Electrical Energy Monitoring\n",
    "\n",
    "To monitor your electrical energy use you would need to measure how many **Watts** are being used by your electrical devices over the time they are being used. Your local power company is able to monitor how much electrical energy you use from an electricity meter attached to the outside of your home. The electricity meter is monitoring the main electrical line running into your home so it can measure the electrical energy used by the entire home. Some examples of electricity meters that you may recognize are below. You may also notice on the images that the electricity meters measure the electrical energy in kWh that we learnt about above. \n",
    "\n",
    "<table>\n",
    "<tr>\n",
    "    <td><img src=\"images/meter2.jpg\" alt=\"1\" width=\"300\"/></td>\n",
    "    <td><img src=\"images/meter.jpg\" alt=\"2\" width=\"300\"/></td>\n",
    "    <td><img src=\"images/meter3.jpg\" alt=\"3\" width=\"300\"/></td>\n",
    "</tr>\n",
    "</table>\n",
    "\n",
    "There are also a variety of smaller electrical meters that can monitor the usage of individual devices and appliances. A few of these meters are below.\n",
    "\n",
    "<table>\n",
    "<tr>\n",
    "    <td><img src=\"images/monitor2.png\" alt=\"1\" width=\"350\"/></td>\n",
    "    <td><img src=\"images/monitor1.jpg\" alt=\"2\" width=\"250\"/></td>\n",
    "    <td><img src=\"images/monitor3.jpg\" alt=\"3\" width=\"350\"/></td>\n",
    "</tr>\n",
    "</table>\n",
    "\n",
    "You can use such devices to monitor the energy consumption of appliances in your house and potentially replace them to energy efficient appliances to save power."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Circuit Diagrams\n",
    "\n",
    "Now that we have covered what electricity is, the various electrical devices and how it is monitored let's take a look at **circuit diagrams**. A circuit diagram is a graphical representation of an **electrical circuit**. An electrical circuit  is a network of electrical devices connected together. All of the electronic devices in your home make up a very complicated electrical circuit that can be represented with a circuit diagram. We are just starting to learn about circuit diagrams so we will be using simple examples such a light bulb connected to a battery that you can see below.\n",
    "\n",
    "<img src=\"images/circuit1.png\"  width=500 >\n",
    "\n",
    "We will cover six different circuit components that can make up a circuit, namely switches, power sources, resistors, lights, motors and wires. \n",
    "\n",
    "1. A **switch** can either be open or closed. If it is open the electricity can't flow through the swtich. If it is closed the electricity can flow through the switch. A switch can be thought of as a light switch. If the light switch is on the electricity is flowing and if it is off the electricity is not.\n",
    "\n",
    "2. A **power source** is any type of device that provides power/electricity. The simple example of a power source we will use is a battery that provides electricity to electrical devices.\n",
    "\n",
    "3. A **resistor** is a component that resists the flow of electricity when it flows through it. The resistor limits the flow of electricity in the circuit. Electrical energy will be lost as heat when electricity flows through a resistor. An example of needing to use a resistor would be when you have two devices in a circuit and one of the devices can only handle so much electricity. You would then need a resistor to limit the flow of electricity to the device. \n",
    "\n",
    "4. A **light** will be some device that produces light. Electrical energy will be lost to this radiant energy as electricity powers the light. The simple example we will use is a light bulb/lamp that generates light.\n",
    "\n",
    "5. A **motor** is a device that is used to convert electrical energy into mechanical energy. Motors are used in a variety of electrical devices ranging from a vehicle motor to a motor in a refrigerator. \n",
    "\n",
    "6. A **wire** is a component that is conductive and allows electricity to flow through it. Wires are used to connect the other various components together.\n",
    "\n",
    "\n",
    "### Units\n",
    "\n",
    "Before we continue on we need to cover some units that are commonly used for the components that make up a circuit. We have already covered **Watts** and **Joules**, we will also cover **Volts**, **Amperes**, **Ohms** and **Coulombs**. \n",
    "\n",
    "A **coulomb (C)** is defined as a of charge. One coulomb is the amount of charge contained in $6.24 \\times 10^{18}$ electrons or 6.24 quintillion electrons.\n",
    "\n",
    "An **ampere (A)** is a unit used to measure electrical current (electricity). It is a measurement of the number of electrons flowing through a circuit. It is defined as one Coulomb of charge passing a certain point in a circuit in one second.\n",
    "\n",
    "A **volt (V)** is a unit of electric potential or electromotive force that causes the electrons to flow. A volt can be defined as the potential difference between two points. In terms of **Joules** and **Coulombs** one volt will impart one joule of energy per coulomb of charge that passes through the two points. The power sources in the circuit will have units of volts as they create the flow of electrons.\n",
    "\n",
    "An **ohm ($\\Omega$)** is a unit of electrical resistance that can be defined as one volt per ampere ($\\Omega = V/A)$ . The higher the resistance in ohms the lower the flow of electricity. As you can guess the resistors have units of ohms since they resist the flow of electricity. Each device in a circuit will also have some resistance to them that slows the flow of the electrons. For example the resistance in a lamp causes it to lose heat energy in addition to the energy emitted as light."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Symbols\n",
    "\n",
    "Each of the components in a circuit are represented by specific symbols as listed below.\n",
    "\n",
    "1. The symbol commonly used for a switch is below. A circuit is considered a closed circuit when all the switches in it are closed and electricity is flowing. When a switch is open in a circuit it is considered an open circuit.\n",
    "\n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/switch.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Open</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/switchclosed.png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Closed</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>\n",
    "\n",
    "2. The symbol for power sources of a single cell battery and double cell battery are below. You can see on the single cell battery there is a positive(+) and negative(-) sign on the two sides. The two signs represent the two terminals on the battery where the long line is the positive terminal and short line is the negative terminal. Electricity flows out of the negative terminal into the circuit and comes back in the positive terminal. \n",
    "\n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/cell.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            1V Battery</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/battery(2V).png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            2V Battery</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>\n",
    "\n",
    "3. The symbol for a resistor is below. There are two commonly used symbols to represent resistors that are below too.\n",
    "\n",
    "    <table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/resistor.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Resistor</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/resistor(1ohm).png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            1 Ohm Resistor</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/resistor(2ohm).png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            2 Ohm Resistor</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "    </table>\n",
    "\n",
    "    There is also a symbol for a variable resistor. This resistor allows the resistance to be adjusted.\n",
    "    \n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/variableresistor.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Variable Resistor</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>\n",
    "\n",
    "4. The symbol for a light bulb/lamp is below.\n",
    "\n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/lamp(1V).png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            1V Lamp</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/lamp(2V).png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            2V Lamp</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>\n",
    "\n",
    "5. The symbol for a motor is below.\n",
    "\n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/motor.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Motor</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>\n",
    "\n",
    "6. The symbol for wires are below.\n",
    "\n",
    "<table>\n",
    "    <tr>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/wire3.png\" alt=\"1\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Straight Wire</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/wire1.png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Corner</div>\n",
    "        </td>\n",
    "        <td>\n",
    "            <div style=\"width:150 px; font-size:120%; text-align:center;\">\n",
    "            <img src=\"images/wire2.png\" alt=\"2\" width=\"150\" style=\"padding-bottom:0.5em\"/>\n",
    "            Link</div>\n",
    "        </td>\n",
    "    </tr>\n",
    "</table>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Creating the Circuit Diagram\n",
    "\n",
    "When you draw a circuit there are two vital components that you will need to make it work. \n",
    "\n",
    "1. A power source to provide electricity to the devices in the circuit \n",
    "2. Wires to connect all the components together and allow electricity to flow through the circuit.\n",
    "\n",
    "The more devices you have connected in your circuit the greater the power sources you will need. This can be achieved by having multiple batteries in a row. For example most TV remotes require at least two batteries in them to give them enough electrical power.\n",
    "\n",
    "Please feel free to play around with the circuit builder program below and build and run your own circuit. The program is from the website http://www.cleo.net.uk/consultants_resources/science/circuitWorld/circuitworld.html and will require you to have Adobe Flash Player download and enabled in your web browser.\n",
    "\n",
    "#### Program Instructions\n",
    "\n",
    "Using this program is relatively simple. The various circuit components/devices we have covered are on the left side and can be clicked on and moved over to the grid to the right. \n",
    "\n",
    "Each of the devices and components will need to be connected together by the wires. \n",
    "\n",
    "Once everything has been connected together you can hit the run button on the bottom left to run the circuit. If the devices don't seem to be working, like a bulb not lighting up you may need to add more batteries to the circuit to provide more electricity.\n",
    "\n",
    "There are other devices and components on the left that we have not covered. They are an ammeter and a buzzer. An ammeter measures the current in a circuit in **amps** and a buzzer just buzzes as expected. Feel free to use those components and devices in the circuit."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<embed src=\"images/circuitworld.swf\" width=\"825\" height=\"600\"></embed></object>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "© 2019 CLEO (Cumbria and Lancashire Education Online)"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from IPython.core.display import HTML\n",
    "display(HTML('<embed src=\"images/circuitworld.swf\" width=\"825\" height=\"600\"></embed></object>'))\n",
    "display(HTML('© 2019 CLEO (Cumbria and Lancashire Education Online)'))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Conclusion\n",
    "\n",
    "In this notebook we have covered a variety of topics related to electricity monitoring and consumption. We looked at what electricity is, the units that it is measured in and the devices used to measure and monitor its consumption. The efficiency of the various electronic devices and appliances used in our homes were looked into to see how much electricity they actually use. We also looked at what circuit diagrams are, how you create them and the various components that a used in them. \n",
    "\n",
    "We have covered a lot of information in this notebook related to electricity and the various devices and appliances that use it but these topics are quite complex so we weren't able to cover everything. I encourage the reader to continue looking into these topics as they are both unique and interesting."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "[![Callysto.ca License](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-bottom.jpg?raw=true)](https://github.com/callysto/curriculum-notebooks/blob/master/LICENSE.md)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
